#include <iostream>
#include <memory>
#include <thread>
#include <chrono>
#include <nlohmann/json.hpp>

#include <drogon/drogon.h>
#include "version.hpp"
#include "assert.hpp"

void crashy() {
    ASSERT(false, "SUCCESS!");
}

int main() {
    std::cout << "ipdemo version: " << ipdemo::VERSION << std::endl;
    std::cout << std::endl;
    std::cout << "Retrieving IP address..." << std::endl;

    // Initialize drogon app but don't run it
    drogon::app().setLogLevel(trantor::Logger::kError);
    
    std::string ip_body;
    int status = 0;
    bool done = false;
    
    // Run in a separate thread to avoid event loop conflicts
    std::thread worker([&]() {
        trantor::EventLoop loop;
        auto client = drogon::HttpClient::newHttpClient("http://ipinfo.io", &loop);
        auto req = drogon::HttpRequest::newHttpRequest();
        req->setMethod(drogon::Get);
        req->setPath("/ip");
        
        client->sendRequest(req, [&](drogon::ReqResult result, const drogon::HttpResponsePtr &resp) {
            if (result == drogon::ReqResult::Ok && resp) {
                ip_body = resp->body();
                status = resp->statusCode();
            } else {
                status = 0;
            }
            done = true;
            loop.quit();
        });
        
        loop.loop();
    });
    
    worker.join();

    ASSERT(status == 200, "Failed to get IP");

    nlohmann::json j;
    j["ip"] = ip_body;
    j["status"] = status;

    std::cout << j.dump(4) << std::endl;

    std::cout << "Done" << std::endl;

    crashy();

    return 0;
}
